==> em_tasks-0.1.5-py2.py3-none-any.whl: em_tasks/utils/sku_parser.py <==
# -*- coding: utf-8 -*-

class SkuParser():
  supported_marketplaces = ['US', 'CA', 'MX', 'UK', 'DE', 'FR', 'IT', 'ES', 'JP', 'TR']

  @classmethod
  def parse(cls, sku):
    source = source_product_id = None
    sku_u = sku.upper().replace('-', '_')
    if sku_u.startswith('X01'):
      source = 'Rakuten'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X02'):
      source = 'Ebay_US'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X03'):
      source = 'Coupang'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X04'):
      source = 'AMZ_JP'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X05'):
      source = 'AMZ_UK'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X06'):
      source = 'AMZ_US'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('AMZ_'):
      parts = sku_u.split('_')
      source_product_id = parts.pop()

      marketplace = None
      for part in parts:
        if part in cls.supported_marketplaces:
          marketplace = part
          break
      if not marketplace:
        marketplace = 'US'
      source = 'AMZ_{}'.format(marketplace)
    elif sku_u.startswith('EBAY_'):
      parts = sku_u.split('_')
      source_product_id = parts.pop()

      marketplace = None
      for part in parts:
        if part in cls.supported_marketplaces:
          marketplace = part
          break
      if not marketplace:
        marketplace = 'US'
      source = 'Ebay_{}'.format(marketplace)
    elif sku_u.startswith('COUPANG_'):
      source = "Coupang"
      parts = sku_u.split('_')
      source_product_id = parts.pop()
    elif sku_u.startswith('EM'):
      source = "EMP"
      source_product_id = sku
    else:
      source = 'Other'
      source_product_id = sku

    return (source, source_product_id)

==> em_tasks-0.1.8-py2.py3-none-any.whl: em_tasks/utils/sku_parser.py <==
# -*- coding: utf-8 -*-

from em_tasks.store.models import StoreSeller


class SkuParser():
  supported_marketplaces = ['US', 'CA', 'MX', 'UK', 'DE', 'FR', 'IT', 'ES', 'JP', 'TR']
  _store_sellers = None

  @classmethod
  def has_store_seller(cls, store_seller_id):
    if cls._store_sellers is None:
      cls._store_sellers = dict()
      for store_seller in StoreSeller.select().execute():
        formatted_ssid = "0:0>10".format(store_seller.id)
        cls._store_sellers[formatted_ssid] = None

    return store_seller_id in cls._store_sellers

  @classmethod
  def parse(cls, sku):
    seller_id = source = source_product_id = None
    sku_u = sku.upper().replace('-', '_')
    if sku_u.startswith('X01'):
      source = 'Rakuten'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X02'):
      source = 'Ebay_US'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X03'):
      source = 'Coupang'
      pars = sku_u.split('_')
      if len(parts) > 2:
        source_product_id = parts[-2]
      else:
        source_product_id = parts.pop()
    elif sku_u.startswith('X04'):
      source = 'AMZ_JP'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X05'):
      source = 'AMZ_UK'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('X06'):
      source = 'AMZ_US'
      source_product_id = sku_u.split('_').pop()
    elif sku_u.startswith('AMZ_'):
      parts = sku_u.split('_')
      source_product_id = parts.pop()

      marketplace = None
      for part in parts:
        if part in cls.supported_marketplaces:
          marketplace = part
          break
      if not marketplace:
        marketplace = 'US'
      source = 'AMZ_{}'.format(marketplace)
    elif sku_u.startswith('EBAY_'):
      parts = sku_u.split('_')
      source_product_id = parts.pop()

      marketplace = None
      for part in parts:
        if part in cls.supported_marketplaces:
          marketplace = part
          break
      if not marketplace:
        marketplace = 'US'
      source = 'Ebay_{}'.format(marketplace)
    elif sku_u.startswith('COUPANG_'):
      source = "Coupang"
      parts = sku_u.split('_')
      if len(parts) > 2:
        source_product_id = parts[-2]
      else:
        source_product_id = parts.pop()
    elif sku_u.startswith('EM'):
      source = "EMP"
      source_product_id = sku
    else:
      source = 'Other'
      source_product_id = sku

    parts = sku_u.split('_')
    if len(parts) >= 3:
      sku_seller_id = parts[1]
      if cls.has_store_seller(sku_seller_id):
        seller_id = sku_seller_id

    return (seller_id, source, source_product_id)
